
def main():
    """Entry point for the application script"""
    print("Call your main application code here")

def filterWellEqual(well,filter,condition):
    output_well = [x for x in well if (filter in x and x[filter] == condition )]
    # count all well retrieved from API
    print("total well count:" , len(well))
    # count well which is actived
    print("filtered well count:" , len(output_well))
    return output_well


import requests
import json

def main():
    """Entry point for the application script"""
    print("Call your main application code here")

def getData(boname,headers,data):
    url = "http://10.134.192.116:8081/dspdm/rest/common/"
    response = requests.request("POST", url,headers= headers, json=data)
    return json.loads(response.text)["data"][boname]["list"]